==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/specialchar/dialogs/lang/cs.js <==
/**
 * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'cs', {
	euro: 'Znak eura',
	lsquo: 'Počáteční uvozovka jednoduchá',
	rsquo: 'Koncová uvozovka jednoduchá',
	ldquo: 'Počáteční uvozovka dvojitá',
	rdquo: 'Koncová uvozovka dvojitá',
	ndash: 'En pomlčka',
	mdash: 'Em pomlčka',
	iexcl: 'Obrácený vykřičník',
	cent: 'Znak centu',
	pound: 'Znak libry',
	curren: 'Znak měny',
	yen: 'Znak jenu',
	brvbar: 'Přerušená svislá čára',
	sect: 'Znak oddílu',
	uml: 'Přehláska',
	copy: 'Znak copyrightu',
	ordf: 'Ženský indikátor rodu',
	laquo: 'Znak dvojitých lomených uvozovek vlevo',
	not: 'Logistický zápor',
	reg: 'Znak registrace',
	macr: 'Pomlčka nad',
	deg: 'Znak stupně',
	sup2: 'Dvojka jako horní index',
	sup3: 'Trojka jako horní index',
	acute: 'Čárka nad vpravo',
	micro: 'Znak mikro',
	para: 'Znak odstavce',
	middot: 'Tečka uprostřed',
	cedil: 'Ocásek vlevo',
	sup1: 'Jednička jako horní index',
	ordm: 'Mužský indikátor rodu',
	raquo: 'Znak dvojitých lomených uvozovek vpravo',
	frac14: 'Obyčejný zlomek jedna čtvrtina',
	frac12: 'Obyčejný zlomek jedna polovina',
	frac34: 'Obyčejný zlomek tři čtvrtiny',
	iquest: 'Znak obráceného otazníku',
	Agrave: 'Velké písmeno latinky A s čárkou nad vlevo',
	Aacute: 'Velké písmeno latinky A s čárkou nad vpravo',
	Acirc: 'Velké písmeno latinky A s vokáněm',
	Atilde: 'Velké písmeno latinky A s tildou',
	Auml: 'Velké písmeno latinky A s dvěma tečkami',
	Aring: 'Velké písmeno latinky A s kroužkem nad',
	AElig: 'Velké písmeno latinky Ae',
	Ccedil: 'Velké písmeno latinky C s ocáskem vlevo',
	Egrave: 'Velké písmeno latinky E s čárkou nad vlevo',
	Eacute: 'Velké písmeno latinky E s čárkou nad vpravo',
	Ecirc: 'Velké písmeno latinky E s vokáněm',
	Euml: 'Velké písmeno latinky E s dvěma tečkami',
	Igrave: 'Velké písmeno latinky I s čárkou nad vlevo',
	Iacute: 'Velké písmeno latinky I s čárkou nad vpravo',
	Icirc: 'Velké písmeno latinky I s vokáněm',
	Iuml: 'Velké písmeno latinky I s dvěma tečkami',
	ETH: 'Velké písmeno latinky Eth',
	Ntilde: 'Velké písmeno latinky N s tildou',
	Ograve: 'Velké písmeno latinky O s čárkou nad vlevo',
	Oacute: 'Velké písmeno latinky O s čárkou nad vpravo',
	Ocirc: 'Velké písmeno latinky O s vokáněm',
	Otilde: 'Velké písmeno latinky O s tildou',
	Ouml: 'Velké písmeno latinky O s dvěma tečkami',
	times: 'Znak násobení',
	Oslash: 'Velké písmeno latinky O přeškrtnuté',
	Ugrave: 'Velké písmeno latinky U s čárkou nad vlevo',
	Uacute: 'Velké písmeno latinky U s čárkou nad vpravo',
	Ucirc: 'Velké písmeno latinky U s vokáněm',
	Uuml: 'Velké písmeno latinky U s dvěma tečkami',
	Yacute: 'Velké písmeno latinky Y s čárkou nad vpravo',
	THORN: 'Velké písmeno latinky Thorn',
	szlig: 'Malé písmeno latinky ostré s',
	agrave: 'Malé písmeno latinky a s čárkou nad vlevo',
	aacute: 'Malé písmeno latinky a s čárkou nad vpravo',
	acirc: 'Malé písmeno latinky a s vokáněm',
	atilde: 'Malé písmeno latinky a s tildou',
	auml: 'Malé písmeno latinky a s dvěma tečkami',
	aring: 'Malé písmeno latinky a s kroužkem nad',
	aelig: 'Malé písmeno latinky ae',
	ccedil: 'Malé písmeno latinky c s ocáskem vlevo',
	egrave: 'Malé písmeno latinky e s čárkou nad vlevo',
	eacute: 'Malé písmeno latinky e s čárkou nad vpravo',
	ecirc: 'Malé písmeno latinky e s vokáněm',
	euml: 'Malé písmeno latinky e s dvěma tečkami',
	igrave: 'Malé písmeno latinky i s čárkou nad vlevo',
	iacute: 'Malé písmeno latinky i s čárkou nad vpravo',
	icirc: 'Malé písmeno latinky i s vokáněm',
	iuml: 'Malé písmeno latinky i s dvěma tečkami',
	eth: 'Malé písmeno latinky eth',
	ntilde: 'Malé písmeno latinky n s tildou',
	ograve: 'Malé písmeno latinky o s čárkou nad vlevo',
	oacute: 'Malé písmeno latinky o s čárkou nad vpravo',
	ocirc: 'Malé písmeno latinky o s vokáněm',
	otilde: 'Malé písmeno latinky o s tildou',
	ouml: 'Malé písmeno latinky o s dvěma tečkami',
	divide: 'Znak dělení',
	oslash: 'Malé písmeno latinky o přeškrtnuté',
	ugrave: 'Malé písmeno latinky u s čárkou nad vlevo',
	uacute: 'Malé písmeno latinky u s čárkou nad vpravo',
	ucirc: 'Malé písmeno latinky u s vokáněm',
	uuml: 'Malé písmeno latinky u s dvěma tečkami',
	yacute: 'Malé písmeno latinky y s čárkou nad vpravo',
	thorn: 'Malé písmeno latinky thorn',
	yuml: 'Malé písmeno latinky y s dvěma tečkami',
	OElig: 'Velká ligatura latinky OE',
	oelig: 'Malá ligatura latinky OE',
	'372': 'Velké písmeno latinky W s vokáněm',
	'374': 'Velké písmeno latinky Y s vokáněm',
	'373': 'Malé písmeno latinky w s vokáněm',
	'375': 'Malé písmeno latinky y s vokáněm',
	sbquo: 'Dolní 9 uvozovka jednoduchá',
	'8219': 'Horní obrácená 9 uvozovka jednoduchá',
	bdquo: 'Dolní 9 uvozovka dvojitá',
	hellip: 'Trojtečkový úvod',
	trade: 'Obchodní značka',
	'9658': 'Černý ukazatel směřující vpravo',
	bull: 'Kolečko',
	rarr: 'Šipka vpravo',
	rArr: 'Dvojitá šipka vpravo',
	hArr: 'Dvojitá šipka vlevo a vpravo',
	diams: 'Černé piky',
	asymp: 'Téměř se rovná'
} );

==> ckeditor_4.10.0+dfsg.orig.tar.xz: ckeditor-dev-4.10.0/plugins/specialchar/dialogs/lang/cs.js <==
/**
 * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'cs', {
	euro: 'Znak eura',
	lsquo: 'Počáteční uvozovka jednoduchá',
	rsquo: 'Koncová uvozovka jednoduchá',
	ldquo: 'Počáteční uvozovka dvojitá',
	rdquo: 'Koncová uvozovka dvojitá',
	ndash: 'En pomlčka',
	mdash: 'Em pomlčka',
	iexcl: 'Obrácený vykřičník',
	cent: 'Znak centu',
	pound: 'Znak libry',
	curren: 'Znak měny',
	yen: 'Znak jenu',
	brvbar: 'Přerušená svislá čára',
	sect: 'Znak oddílu',
	uml: 'Přehláska',
	copy: 'Znak copyrightu',
	ordf: 'Ženský indikátor rodu',
	laquo: 'Znak dvojitých lomených uvozovek vlevo',
	not: 'Logistický zápor',
	reg: 'Znak registrace',
	macr: 'Pomlčka nad',
	deg: 'Znak stupně',
	sup2: 'Dvojka jako horní index',
	sup3: 'Trojka jako horní index',
	acute: 'Čárka nad vpravo',
	micro: 'Znak mikro',
	para: 'Znak odstavce',
	middot: 'Tečka uprostřed',
	cedil: 'Ocásek vlevo',
	sup1: 'Jednička jako horní index',
	ordm: 'Mužský indikátor rodu',
	raquo: 'Znak dvojitých lomených uvozovek vpravo',
	frac14: 'Obyčejný zlomek jedna čtvrtina',
	frac12: 'Obyčejný zlomek jedna polovina',
	frac34: 'Obyčejný zlomek tři čtvrtiny',
	iquest: 'Znak obráceného otazníku',
	Agrave: 'Velké písmeno latinky A s čárkou nad vlevo',
	Aacute: 'Velké písmeno latinky A s čárkou nad vpravo',
	Acirc: 'Velké písmeno latinky A s vokáněm',
	Atilde: 'Velké písmeno latinky A s tildou',
	Auml: 'Velké písmeno latinky A s dvěma tečkami',
	Aring: 'Velké písmeno latinky A s kroužkem nad',
	AElig: 'Velké písmeno latinky Æ',
	Ccedil: 'Velké písmeno latinky C s ocáskem vlevo',
	Egrave: 'Velké písmeno latinky E s čárkou nad vlevo',
	Eacute: 'Velké písmeno latinky E s čárkou nad vpravo',
	Ecirc: 'Velké písmeno latinky E s vokáněm',
	Euml: 'Velké písmeno latinky E s dvěma tečkami',
	Igrave: 'Velké písmeno latinky I s čárkou nad vlevo',
	Iacute: 'Velké písmeno latinky I s čárkou nad vpravo',
	Icirc: 'Velké písmeno latinky I s vokáněm',
	Iuml: 'Velké písmeno latinky I s dvěma tečkami',
	ETH: 'Velké písmeno latinky Eth',
	Ntilde: 'Velké písmeno latinky N s tildou',
	Ograve: 'Velké písmeno latinky O s čárkou nad vlevo',
	Oacute: 'Velké písmeno latinky O s čárkou nad vpravo',
	Ocirc: 'Velké písmeno latinky O s vokáněm',
	Otilde: 'Velké písmeno latinky O s tildou',
	Ouml: 'Velké písmeno latinky O s dvěma tečkami',
	times: 'Znak násobení',
	Oslash: 'Velké písmeno latinky O přeškrtnuté',
	Ugrave: 'Velké písmeno latinky U s čárkou nad vlevo',
	Uacute: 'Velké písmeno latinky U s čárkou nad vpravo',
	Ucirc: 'Velké písmeno latinky U s vokáněm',
	Uuml: 'Velké písmeno latinky U s dvěma tečkami',
	Yacute: 'Velké písmeno latinky Y s čárkou nad vpravo',
	THORN: 'Velké písmeno latinky Thorn',
	szlig: 'Malé písmeno latinky ostré s',
	agrave: 'Malé písmeno latinky a s čárkou nad vlevo',
	aacute: 'Malé písmeno latinky a s čárkou nad vpravo',
	acirc: 'Malé písmeno latinky a s vokáněm',
	atilde: 'Malé písmeno latinky a s tildou',
	auml: 'Malé písmeno latinky a s dvěma tečkami',
	aring: 'Malé písmeno latinky a s kroužkem nad',
	aelig: 'Malé písmeno latinky ae',
	ccedil: 'Malé písmeno latinky c s ocáskem vlevo',
	egrave: 'Malé písmeno latinky e s čárkou nad vlevo',
	eacute: 'Malé písmeno latinky e s čárkou nad vpravo',
	ecirc: 'Malé písmeno latinky e s vokáněm',
	euml: 'Malé písmeno latinky e s dvěma tečkami',
	igrave: 'Malé písmeno latinky i s čárkou nad vlevo',
	iacute: 'Malé písmeno latinky i s čárkou nad vpravo',
	icirc: 'Malé písmeno latinky i s vokáněm',
	iuml: 'Malé písmeno latinky i s dvěma tečkami',
	eth: 'Malé písmeno latinky eth',
	ntilde: 'Malé písmeno latinky n s tildou',
	ograve: 'Malé písmeno latinky o s čárkou nad vlevo',
	oacute: 'Malé písmeno latinky o s čárkou nad vpravo',
	ocirc: 'Malé písmeno latinky o s vokáněm',
	otilde: 'Malé písmeno latinky o s tildou',
	ouml: 'Malé písmeno latinky o s dvěma tečkami',
	divide: 'Znak dělení',
	oslash: 'Malé písmeno latinky o přeškrtnuté',
	ugrave: 'Malé písmeno latinky u s čárkou nad vlevo',
	uacute: 'Malé písmeno latinky u s čárkou nad vpravo',
	ucirc: 'Malé písmeno latinky u s vokáněm',
	uuml: 'Malé písmeno latinky u s dvěma tečkami',
	yacute: 'Malé písmeno latinky y s čárkou nad vpravo',
	thorn: 'Malé písmeno latinky thorn',
	yuml: 'Malé písmeno latinky y s dvěma tečkami',
	OElig: 'Velká ligatura latinky OE',
	oelig: 'Malá ligatura latinky OE',
	'372': 'Velké písmeno latinky W s vokáněm',
	'374': 'Velké písmeno latinky Y s vokáněm',
	'373': 'Malé písmeno latinky w s vokáněm',
	'375': 'Malé písmeno latinky y s vokáněm',
	sbquo: 'Dolní 9 uvozovka jednoduchá',
	'8219': 'Horní obrácená 9 uvozovka jednoduchá',
	bdquo: 'Dolní 9 uvozovka dvojitá',
	hellip: 'Trojtečkový úvod',
	trade: 'Obchodní značka',
	'9658': 'Černý ukazatel směřující vpravo',
	bull: 'Kolečko',
	rarr: 'Šipka vpravo',
	rArr: 'Dvojitá šipka vpravo',
	hArr: 'Dvojitá šipka vlevo a vpravo',
	diams: 'Černé piky',
	asymp: 'Téměř se rovná'
} );
